@@ -25,12 +25,13 @@ import sys
 import os
 import stat
 
-from base import JsPp
-from base import NoTrailingSpace
-from parser import UiParser
-
 import jsqt
 
+from jsqt.base import JsPp
+from jsqt.base import NoTrailingSpace
+from jsqt.parser import UiParser
+
+
 def walktree(top = ".", depthfirst = False):
     names = os.listdir(top)
     if not depthfirst:
@@ -62,7 +63,7 @@ def compile(ui_file_name, js_file_name, root_namespace, base_class, dialect):
     object_name= js_file_name[js_file_name.rfind(root_namespace):].replace(
                                     os.sep*2, os.sep).replace(os.sep, ".")[0:-3]
     parser = UiParser(object_name)
-    parser.parse(ui_file_name)
+    parser.parse(ui_file_name, ui_file_name)
     parser.clazz.base_class = base_class
 
     jsqt.debug_print("")
@@ -71,6 +72,8 @@ def compile(ui_file_name, js_file_name, root_namespace, base_class, dialect):
     compiled_object = parser.clazz.compile(dialect)
 
     f=open(js_file_name, 'w')
+    for p in parser.clazz.preamble:
+        p.compile(dialect).to_stream(f)
     compiled_object.to_stream(JsPp(NoTrailingSpace(f)))
     f.write(";\n") # FIXME: Hack!
     f.close()
@@ -170,7 +173,7 @@ def main_jsuic():
 
 
     parser = UiParser()
-    parser.parse(input_file)
+    parser.parse(input_file, input_file_name)
     parser.clazz.base_class = base_class
     compiled_object = parser.clazz.compile('javascript-qooxdoo-1.6')
 
