@@ -1,5 +1,4 @@
 # encoding: utf8
-
 #
 # This file is part of JsQt.
 #
@@ -38,7 +37,6 @@ class SinglePartCompilable(Compilable):
         dialect -- a string representing the dialect of the output
 
         Returns the compiled language fragment
-
         """
 
         raise NotImplementedError("Please override for class '%s.%s'" % (self.__module__,
@@ -113,8 +111,7 @@ class Boolean(SinglePartCompilable):
         return js.primitive.Boolean(self.__value)
 
 class Enum(SinglePartCompilable):
-    """Need to sublass this and add mapping values. It's not useful as it is."""
-
+    """You need to sublass this and add mapping values."""
     value_map = None
     
     def __init__(self, value):
@@ -122,6 +119,9 @@ class Enum(SinglePartCompilable):
 
         self.__value = self.value_map[value]
 
+    def get_value(self):
+        return self.__value
+
     @classmethod
     def from_elt(cls, elt):
         return cls(elt.text)
@@ -178,7 +178,7 @@ class String(SinglePartCompilable):
     def __init__(self, string):
         SinglePartCompilable.__init__(self)
 
-        self._string=str(string)
+        self._string = str(string)
 
     @staticmethod
     def from_elt(elt):
@@ -207,7 +207,9 @@ class TranslatableString(String):
 
     @staticmethod
     def from_elt(elt):
-        if elt.text is None:
+        if elt.attrib.get('notr', None) == 'true':
+            return String.from_elt(elt)
+        elif elt.text is None:
             return TranslatableString("")
         else:
             return TranslatableString(elt.text)
@@ -358,6 +360,7 @@ class ClassDefinition(SinglePartCompilable):
         self.mixins = DuckTypedList(['compile'])
         self.mixins.append(ObjectReference("qx.locale.MTranslation"))
         self.base_class = None
+        self.assets = set()
 
     def set_name(self, name):
         self.__name = name
@@ -391,11 +394,11 @@ class ClassDefinition(SinglePartCompilable):
         # anywhere, including members dict.
         for k,v in self.members.items():
             if isinstance(v, MultiPartCompilable): # FIXME!
-                v.compile(dialect,self)
+                v.compile(dialect, self)
 
         for k,v in self.members.items():
             if isinstance(v, SinglePartCompilable): # FIXME!
-                class_members.set_member(k,v.compile(dialect))
+                class_members.set_member(k, v.compile(dialect))
 
         st = FunctionCall('this.base')
         st.add_argument(ObjectReference('arguments'))
@@ -404,7 +407,7 @@ class ClassDefinition(SinglePartCompilable):
         properties = js.primitive.Object()
         widget_property = js.primitive.Object()
         widget_property.set_member("check",
-                               js.primitive.String('qx.ui.container.Composite'))
+                               js.primitive.String('qx.ui.core.Widget'))
         properties.set_member("widget", widget_property)
 
         mixins = js.primitive.Array()
@@ -420,6 +423,9 @@ class ClassDefinition(SinglePartCompilable):
         class_dict.set_member("include", mixins)
 
         lang.add_argument(class_dict)
+        if len(self.assets) > 0:
+            self.preamble.insert(0, Comment("".join(
+                    ["\n#asset(%s)" % a for a in sorted(self.assets)]) + "\n"))
 
         return lang
 
