@@ -1,5 +1,4 @@
 # encoding: utf8
-
 #
 # This file is part of JsQt.
 #
@@ -25,9 +24,10 @@ import jsqt
 
 from jsqt import il
 from jsqt.xml import etree
+from jsqt.il.qt import gui
+from jsqt.il.qt import obj
+
 from base import SimpleProp
-import gui
-import obj
 
 class Base(gui.WidgetBase):
     add_method_name = "add"
@@ -137,7 +137,7 @@ class WithoutLayout(Base):
 class QWidget(Base):
     type = "qx.ui.container.Composite"
 
-class QMainWindow(Base):
+class QDialog(Base):
     type = "qx.ui.container.Composite"
 
     def __init__(self, elt, name=None):
@@ -173,6 +173,15 @@ class QMainWindow(Base):
         for i in range(len(self.children)):
             self._compile_child(dialect, ret, self.children[i])
 
+class _FakeAttrib(object):
+    def __init__(self, value):
+        self.value = value
+
+class QMainWindow(QDialog):
+    def __init__(self, elt, name=None):
+        QDialog.__init__(self, elt, name)
+        self.set_layout(il.qt.layout.QVBoxLayout(None,"__lv"))
+
 class QTabWidget(WithoutLayout):
     type = "qx.ui.tabview.TabView"
     
@@ -191,6 +200,13 @@ class TabPage(Base):
         self.layout_properties = None
         Base.__init__(self, elt, name)
 
+class EnumOrientation(il.primitive.Enum):
+    value_map = {
+        "Qt::Vertical": "vertical",
+        "Qt::Horizontal": "horizontal",
+    }
+
+
 class QSplitter(Base):
     type = "qx.ui.splitpane.Pane"
 
@@ -222,7 +238,7 @@ class QSplitter(Base):
         instantiation = il.primitive.Assignment()
         instantiation.left = il.primitive.ObjectReference('this.%s' % self.name)
         instantiation.right = il.primitive.Instantiation(self.type,[
-            il.primitive.String(self.__orientation)])
+            il.primitive.String(self.__orientation.get_value())])
 
         self.factory_function.add_statement(instantiation)
         self.factory_function.add_statement(il.primitive.VariableDeclaration(
@@ -236,6 +252,13 @@ class QSplitter(Base):
 
         ret.set_member(self.name, il.primitive.ObjectReference('null'))
 
+    def _handle_prop_orientation(self, elt):
+        self.__orientation = EnumOrientation(elt.find('enum').text)
+
+    known_complex_props = {
+        "orientation": _handle_prop_orientation,
+    }
+
 class QGroupBox(Base):
     type = "qx.ui.groupbox.GroupBox"
     known_simple_props = {
